.. nodoctest

The class ``FinitelyGeneratedSubgroup``
=======================================

.. automodule:: stallings_graphs.finitely_generated_subgroup
   :members:
   :undoc-members:
   :show-inheritance:
   

